
-------------------------------------------------------------------------------
-- TIDY PLATES FISH THEME  (For Version 5)
-------------------------------------------------------------------------------
				
-- Define a local variable to hold your configuration table
local config = {}

-- Define a variable to store the folder texturepath (for convenience)
local fontpath = "Interface\\Addons\\TidyPlates_Fish\\fonts\\"
local texturepath = "Interface\\Addons\\TidyPlates_Fish\\textures\\"

-------------------------------------------------------------------------------

--[[ NAMEPLATE FRAME ELEMENTS
In the next section, we will define the appearance of the nameplates.  
You don't have to set each and every parameter; Tidy Plates will analyze 
the table and only use values that have been changed.
]]

-------------------------------------------------------------------------------


				--[[ ALIGNMENT FRAME
				The Alignment Frame is used to define the size of the clickable unit
				button.  It also serves as an alignment tool for the rest of the
				layout.

				.width, .height 	= The size of the clickable unit button
				]]
				
config.frame = {
	width = 135,
	height = 45,
}

				--[[ HEALTH BORDER 
				The Health Border is an overlay that sits above the health status- 
				bar. It incorporates an alpha channel, which can be used for neat 
				effects. 

				.width, .height 	= The final on-screen size of the artwork
				.x, ,y				= Offset of the overlay artwork, relative to
										the Alignment Frame
				.anchor				= Sets the anchor-point and anchor-target.
										The anchor-target frame is the
										Alignment Frame (see previous section). 
				.texture			= The texture to be used for regular 
										mobs (BLP or TGA)
				.elitetexture 		= The texture for elite mobs
				.glowtexture		= Added to the overlay during mouseover

				Note: Designing the graphics in a layering editor ( like Photoshop, 
				GIMP, Paint.net, etc.) is a good method.  Either BLP or TGA images 
				are	supported.  No file extension is needed in LUA.
				 ]]
				 
config.healthborder = {
	texture = texturepath.."Shade",
	glowtexture = texturepath.."Highlight",
	elitetexture = texturepath.."ShadeElite",
	width = 134,
	height = 36,
	x = -1,
	y = 0,
	anchor = "CENTER",
}

				--[[ THREAT BORDER 
				The Threat Border is an overlay that sits above the health-bar 
				overlay, and provides indication of the mob's aggro state.
				 ]]
				 
config.threatborder = {
	texture =					texturepath.."Threat",
	elitetexture =			texturepath.."ThreatElite",
	width = 134,
	height = 36,
	x = -1,
	y = 0,
	anchor = "CENTER",
}
					
				--[[ SPELLCAST BORDER 
				The Cast Border is an overlay that sits above the health-bar overlay.
				It's only shown during a spellcast or while channeling.  The casting 
				status-bar and spell icon sit underneath.
				 ]]

config.castborder = {
	texture =					texturepath.."CastShade",
	width = 110,
	height = 25,
	x = -3,
	y = -25,
	anchor = "CENTER",
}

				--[[ NAME TEXT 
				The automatically generated unit name.

				.width, .height 	= The final on-screen size of the text box
										Text will wrap around, if it's too long
										to fit in the defined box
				.x, ,y				= Offset of the text box, relative to
										the Alignment Frame
				.anchor				= Anchor to both Health Border and 
										Alignment Frame
				.typeface			= texturepath to font file.  TTFs are supported
				.size				= Font size
				.shadow				= Should a shadow be displayed?
				.align				= Justify the text horizontally
				.vertical			= Justify the text vertically
				 ]]
				 
config.name = {
	typeface =					fontpath.."MILFCD_B.ttf",
	size = 18,
	width = 120,
	height = 24,
	x = 15,
	y = -3,
	align = "LEFT",
	anchor = "LEFT",
	vertical = "BOTTOM",
	shadow = false,
	flags = "OUTLINE",
}

				--[[ LEVEL TEXT 
				The automatically generated level text.
				 ]]
				 
config.level = {
	typeface =					fontpath.."MILFCD_B.ttf",
	size = 20,
	width = 30,
	height = 24,
	x = -2,
	y = 17,
	align = "RIGHT",
	anchor = "LEFT",
	vertical = "BOTTOM",
	shadow = false,
	flags = "OUTLINE",
}

				--[[ SKULL ICON
				Shown when an enemy is WAY above your level, or is an NPC boss.
				]]
				
config.dangerskull = {
	width = 14,
	height = 14,
	x = -13,
	y = 16,
	anchor = "LEFT",
}

				--[[  HEALTH BAR 
				When you're designing a status bar image, you'll have to keep a
				few things in mind:

				* You can use the alpha channel to alter the opacity, allowing
					effects such as rounded corners, or novelty shapes.
				* The Blizzard client will automatically recolor the image for
					the specific unit. Example: For hostile targets, only the 
					red channel will be used. For neutral characters, the red
					and green channels will be displayed.  For best results,
					design your statusbar image in greyscale.
				 ]]
				 
config.healthbar = {
	texture =					 texturepath.."Statusbar",
	width =128,
	height = 28,
	x = 0,
	y = 0,
	anchor = "CENTER",
	orientation = "HORIZONTAL",
}

				--[[  SPELL-CASTING BAR
				Shown during casting; See HEALTH BAR for property description.
				Note: The cast bar is only shown for the current target.  That
				is a Blizzard limitation.
				]]
				
config.castbar = {
	texture =					texturepath.."CastStatusbar",
	width = 105,
	height = 19,
	x = -3,
	y = -25,
	anchor = "CENTER",
	orientation = "HORIZONTAL",
}

				--[[ SPELL ICON
				Shown during casting; Shows the icon of the spell that's being cast.
				]]

config.spellicon = {
	width = 15,
	height = 15,
	x = 62,
	y = -25,
	anchor = "CENTER",
}

				--[[  RAID ICON
				The raid target icons ie. Lucky Charms
				]]
				
config.raidicon = {
	width = 14,
	height = 14,
	x = 0,
	y = 12,
	anchor = "TOP",
}

				--[[ THREAT COLOR
				The threat conditions come directly from Blizzard's own nameplates.
				You can alter the colors, to your own preference.
				LOW - For tanks, this means that you've lost threat.  For DPS, this means that you're avoiding aggro.
				MEDIUM - This means that you're CLOSE to drawing aggro
				HIGH - This means that you've drawn aggro, and are securely tanking.
				Certain abilities (Challenging Shout/Challenging Roar/Death Grip) are not true taunts, and will not
				indicate that you've drawn aggro.
				]]
				
config.threatcolor = {
	LOW = { r = .65, g = 1, b = 0, a= 0, },
	MEDIUM = { r = .75, g = 1, b = 0, a = 0.9, },
	HIGH = { r = .75, g = 0, b = 0, a = 1, },
}
				
				--[[  SPECIAL TEXT
				This text is controlled by a user-defined function
				The function is passed unit information.
				Using escape codes, you can control color and transparency
				See DELEGATE FUNCTION section, below
				]]

config.specialText = {
	typeface =					fontpath.."MILFCD_B.ttf",
	size = 12,
	width = 95,
	height = 14,
	x = 5,
	y = 14,
	align = "LEFT",
	anchor = "LEFT",
	vertical = "BOTTOM",
	shadow = true,
}

				--[[  PLATE OPTIONS
				Turning on and off different options
				]]

config.options = {
	showLevel = true,
	showName = true,
	showSpecialText = false,
	showDangerSkull = false,
	showspellIcon = true,
}

-------------------------------------------------------------------------------

				--[[  POSTING YOUR THEME TO THE GLOBAL ARRAY
				This registers the theme to a specific global array.
				Tidy Plates will look for this array, and all themes that
				are contained.  Simply change the "Sample" to the name 
				of your theme (Don't use spaces or funny letters)
				]]
				
if not TidyPlatesThemeList then TidyPlatesThemeList = {} end
TidyPlatesThemeList["Fish"] = config

-------------------------------------------------------------------------------

--[[ DELEGATE FUNCTIONS
Delegate Functions allow you to customize delivered
information based on the associated unit.  Tidy Plates
will pass a table to the function, which contains 
information that it was able to glean from the
nameplate frame.

Table Members:
	*  unit.threatSituation = "LOW", "MEDIUM", or "HIGH"
	*  unit.reaction = "FRIENDLY", or "NOTFRIENDLY"
	*  unit.isElite = true or false
	*  unit.name = String
	*  unit.level = Number
	*  unit.health = Number
	*  unit.healthmax = Number
	
Mind the fact that mobs may have identical names.
]]

-------------------------------------------------------------------------------

				--[[  SET SPECIAL TEXT FUNCTION
				To use the Special Text feature, you'll need to make sure it's 
				enabled (look above, in config.options).  Once it's enabled, you 
				can create your function.  Tidy Plates will provide the function 
				with a table of information, and the function should return a 
				string.  This string can be formatted using 'escape sequences'.
				http://www.wowwiki.com/UI_Escape_Sequences
				
				Here's an example of what you could do:
				* Display Health or Health-Delta
				* Display a hint to use a certain spell (when under or over
					a certain health mark)
				* Display a "Friend" tag, if the unit is on your
					friends list.
				* You could even link the function to a Wowhead database of mob 
					names, and display warnings or hints.  It'd be a neat thing 
					to have the text display something like, "Whirlwind" for 
					mobs that have the ability, or "Healer" for mobs that can 
					heal.
				]]

				
function config.SetSpecialText(unit)
	-- Returns a string with the unit's health, over it's maximum health.
	return unit.health.." / "..unit.healthmax
end			

				--[[  SET ALPHA FUNCTION
				Like the SetSpecialText function, the SetAlpha function allows 
				you to change the transparency of the nameplate based on unit
				information.  The function should return a value ranged from 
				0.0 to 1.0.
				
				Since Blizzard's software controls the opacity of the parent 
				plate frame, and the plate is protected during combat, we can
				only modify the relative opacity of each element, compared to
				the parent opacity.  If Blizzard has the nameplate frame at
				50% opacity, we can only go lower.
				]]
				
function config.SetAlpha(unit)
			-- Sets the nameplate at 100% relative opacity if the unit has 90% or 
			-- more health.  If the unit has less than 90% of its health, the
			-- function returns 60%.  This can be helpful to see what units
			-- are getting healed to full. (Like Emalon's Minions - hint hint)
	if (unit.health / unit.healthmax) > 0.8 then return 1
	else return .8 end
end




